@@ -173,6 +173,8 @@ def generate_config_id(config):
     config_id = ""
     for key in config:
         config_id += str(config[key]) + "_"
+        # hash the config_id to make it shorter and unique
+        config_id = str(hash(config_id)) + "_"
     return config_id[:-1]
 
 
@@ -278,7 +280,7 @@ def plot_sns_heatmap(
     fmt=".5f",
     linewidths=0.5,
     annot_kws={"size": 8},
-):
+) -> None:
     """
     Plots a heatmap of the correlation matrix of the given DataFrame.
 
@@ -294,7 +296,7 @@ def plot_sns_heatmap(
         annot_kws (dict): Keyword arguments for annotations.
 
     Returns:
-        None
+        (NoneType): None
 
     Example:
         >>> import pandas as pd
@@ -318,7 +320,7 @@ def plot_sns_heatmap(
     plt.gcf().clear()
 
 
-def count_missing_data(df):
+def count_missing_data(df) -> pd.DataFrame:
     """
     Counts the number of missing values in each column of the given DataFrame.
 
@@ -326,7 +328,7 @@ def count_missing_data(df):
         df (pd.DataFrame): DataFrame containing the data to be counted.
 
     Returns:
-        pd.DataFrame: DataFrame containing the number of missing values in each column.
+        (pd.DataFrame): DataFrame containing the number of missing values in each column.
 
     Example:
         >>> import pandas as pd
@@ -344,7 +346,9 @@ def count_missing_data(df):
     return missing_df
 
 
-def plot_missing_data(df, relative=False, figsize=(7, 5), color="grey", xlabel="Missing Data", title="Missing Data"):
+def plot_missing_data(
+    df, relative=False, figsize=(7, 5), color="grey", xlabel="Missing Data", title="Missing Data"
+) -> None:
     """
     Plots a horizontal bar chart of the number of missing values in each column of the given DataFrame.
 
@@ -357,7 +361,7 @@ def plot_missing_data(df, relative=False, figsize=(7, 5), color="grey", xlabel="
         title (str): Title for the plot.
 
     Returns:
-        None
+        (NoneType): None
 
     Example:
         >>> import pandas as pd
